@@ -1,10 +1,10 @@
-/* Copyright (C) 2001 Chris Vaill
+/* Copyright (C) 2001--2005 Chris Vaill
    This file is part of nid3lib.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 /*
  * General tag and frame manipulation routines
@@ -666,7 +666,9 @@ _read_v4_frame_data(id3_frame_t f)
   if (tag->seekable)
     if (fseek(tag->fp, f->offset, SEEK_SET) == -1)
       tag->seekable = 0;
-  f->data = (unsigned char *)malloc(f->sz + 2);
+
+  /* calloc instead of malloc to ensure termination of text data */
+  f->data = (unsigned char *)calloc(f->sz + 2, 1);
   if (f->data == NULL)
     goto error;
   if (fread(f->data, 1, f->sz, tag->fp) < f->sz)
@@ -675,9 +677,7 @@ _read_v4_frame_data(id3_frame_t f)
     f->sz = decode_unsync(f->data, f->data, f->sz);
 
   if (f->id[0] == 'T') {
-    /* for text frames, ensure termination at end */
-    f->data[f->sz] = f->data[f->sz+1] = 0;
-    /* and set the curr_txt pointer */
+    /* for text frames, set the curr_txt pointer */
     f->curr_txt = f->data + 1;
   }
 
@@ -773,7 +773,8 @@ _read_v3_frame_data(id3_frame_t f)
     if (fseek(tag->fp, f->offset, SEEK_SET) == -1)
       tag->seekable = 0;
 
-  f->data = (unsigned char *)malloc(f->sz + 2);
+  /* calloc instead of malloc to ensure termination of text data */
+  f->data = (unsigned char *)calloc(f->sz + 2, 1);
   if (f->data == NULL)
     goto error;
   if (tag->unsync) {
@@ -787,9 +788,7 @@ _read_v3_frame_data(id3_frame_t f)
   }
 
   if (f->id[0] == 'T') {
-    /* for text frames, ensure termination at end */
-    f->data[f->sz] = f->data[f->sz+1] = 0;
-    /* and set the curr_txt pointer */
+    /* for text frames, set the curr_txt pointer */
     f->curr_txt = f->data + 1;
   }
 
@@ -836,9 +835,12 @@ _read_v3_frame_headers(id3_t tag)
       /*
        * Read the non-unsynced frame header normally.
        */
-      /* +10 to offset because we want to read that many,
-       * +10 to tagsz because it doesn't include the header */
-      if (tag->curr_off + 10 > tagsz + 10)
+      /* The next line, if written for readability, would be
+       *     if (tag->curr_off + 10 > tagsz + 10)
+       * because:
+       *     +10 to offset because we want to read that many,
+       *     +10 to tagsz because it doesn't include the header */
+      if (tag->curr_off > tagsz)
 	break;
       if (fread(buf, 1, 10, tag->fp) < 10)
 	goto error;
@@ -1113,7 +1115,8 @@ id3_set_size(id3_t tag, int size)
  * @see id3_set_size()
  * @see id3_get_pad_policy()
  * @param tag the tag
- * @param policy the padding policy */
+ * @param policy the padding policy
+ */
 void
 id3_set_pad_policy(id3_t tag, enum id3_pad_policy policy)
 {
