@@ -1,10 +1,10 @@
-/* Copyright (C) 2001 Chris Vaill
+/* Copyright (C) 2001--2005 Chris Vaill
    This file is part of nid3lib.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -706,8 +706,8 @@ find_converter(const struct frame_convert *map, const char *from, int backw)
 static int
 convert_frame(id3_frame_t f, int from_vers, int to_vers)
 {
-  const struct frame_convert *fc_map;
-  int ret, backward;
+  const struct frame_convert *fc_map = NULL;
+  int ret, backward = 0;
   const char *newid;
 
   if (from_vers == to_vers)
