@@ -1,10 +1,10 @@
-/* Copyright (C) 2001 Chris Vaill
+/* Copyright (C) 2001--2005 Chris Vaill
    This file is part of nid3lib.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 /*
  * This file contains a single externally visible function,
@@ -431,6 +431,7 @@ _write_v3_frames(id3_t tag, FILE *out)
 static void
 _build_v1_tag(unsigned char *buf, id3_t tag)
 {
+  /* FIXME: copy appropriate existing v2 tags to their v1 counterparts? */
   memset(buf, 0, 128);
   strcpy(buf, "TAG");
   strncpy(buf + 3, tag->v1.title, 30);
@@ -488,7 +489,7 @@ _calculate_tag_sizes(id3_t tag, int *pold_sz, int *pnew_sz)
 	/* for 256 < new_tagsz <= 32768, pad up to nearest power of 2 */
 	padded_sz = 1;
 	new_tagsz--;
-	while (new_tagsz > 1) {
+	while (new_tagsz > 0) {
 	  padded_sz <<= 1;
 	  new_tagsz >>= 1;
 	}
