@@ -1,10 +1,10 @@
-/* Copyright (C) 1999--2002 Chris Vaill
+/* Copyright (C) 1999--2005 Chris Vaill
    This file is part of normalize.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -296,7 +296,8 @@ _do_apply_gain(int read_fd, int write_fd, char *filename, double gain,
   /*
    * Change gain to account for different output sample width
    */
-  gain *= pow(256.0, dst_bytes_per_samp - src_bytes_per_samp);
+  if (dst_bytes_per_samp != src_bytes_per_samp)
+    gain *= pow(256.0, dst_bytes_per_samp - src_bytes_per_samp);
 
 
 #if USE_LOOKUPTABLE
@@ -533,14 +534,16 @@ apply_gain(char *filename, double gain, struct signal_info *si)
   i = strlen(filename);
   if (i >= 4) {
     suffix = filename + i - 4;
-    if (strncaseeq(suffix, ".mp3", 4))
+    if (strncaseeq(suffix, ".mp3", 4)
+	|| strncaseeq(suffix, ".mp2", 4))
       return apply_gain_mp3(filename, gain, si);
   }
 
+  dBdiff = FRACTODB(gain);
+
   /* if !do_compute_levels, -g was specified, so we force the adjust */
   if (do_compute_levels) {
-    dBdiff = fabs(FRACTODB(gain));
-    if (dBdiff < adjust_thresh) {
+    if (fabs(dBdiff) < adjust_thresh) {
       /* gain is below the threshold, so don't apply */
       return 0;
     }
