@@ -1,10 +1,10 @@
-/* Copyright (C) 1999--2001 Chris Vaill
+/* Copyright (C) 1999--2005 Chris Vaill
    This file is part of normalize.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 /* interface to the mad decoding library */
 
@@ -203,6 +203,8 @@ signal_max_power_mp3(char *filename, struct signal_info *si)
 		   decode_error /* error */,
 		   NULL /* message */);
 
+  mad_decoder_options(&decoder, MAD_OPTION_IGNORECRC);
+
   result = mad_decoder_run(&decoder, MAD_DECODER_MODE_SYNC);
 
   mad_decoder_finish(&decoder);
