@@ -1,10 +1,10 @@
-/* Copyright (C) 1999--2001 Chris Vaill
+/* Copyright (C) 1999--2005 Chris Vaill
    This file is part of normalize.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*/
 
 #define _POSIX_C_SOURCE 2
 
@@ -105,7 +105,7 @@ usage()
 {
   printf(_("\
 Usage: %s [OPTION]... [FILE]...\n\
-Normalize volume of multiple WAV files\n\
+Normalize volume of multiple audio files\n\
 \n\
   -a, --amplitude=AMP          normalize the volume to the target amplitude\n\
                                  AMP [default -12dBFS]\n\
@@ -137,7 +137,7 @@ Normalize volume of multiple WAV files\n\
   -V, --version                display version information and exit\n\
   -h, --help                   display this help and exit\n\
 \n\
-Report bugs to <cvaill@cs.columbia.edu>.\n"), progname);
+Report bugs to <chrisvaill@gmail.com>.\n"), progname);
 }
 
 enum {
@@ -603,7 +603,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 	}
 	/* frontend mode: print "ADJUSTED <number> 1|0" */
 	if (frontend)
-	  printf("ADJUSTED %d %f\n", sis[i].orig_index, ret);
+	  printf("ADJUSTED %d %d\n", sis[i].orig_index, ret);
       }
 
       progress_info.finished_size += progress_info.file_sizes[i];
